@@ -63,7 +63,7 @@
 #define MAXFONTNAMELEN 1024
 #endif
 
-char *encodings_array[] =
+static char *encodings_array[] =
     { "ascii-0",
       "iso8859-1", "iso8859-2", "iso8859-3", "iso8859-4", "iso8859-5",
       "iso8859-6", "iso8859-6.8", "iso8859-6.8x", "iso8859-6.16",
@@ -82,11 +82,11 @@ char *encodings_array[] =
       "gb2312.1980-0", "gb18030.2000-0", "gb18030.2000-1",
       "ksc5601.1987-0", "ksc5601.1992-3"};
 
-char *extra_encodings_array[] =
+static char *extra_encodings_array[] =
     { "iso10646-1", "adobe-fontspecific", "microsoft-symbol" };
 
-ListPtr encodings, extra_encodings;
-char *outfilename;
+static ListPtr encodings, extra_encodings;
+static char *outfilename;
 
 #define countof(_a) (sizeof(_a)/sizeof((_a)[0]))
 
